Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1211)

Unified Diff: Source/core/layout/LayoutTextFragment.h

Issue 940373003: Rename RenderText to LayoutText (Closed) Base URL: https://chromium.googlesource.com/chromium/blink.git@master
Patch Set: Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/layout/LayoutTextCombine.cpp ('k') | Source/core/layout/LayoutTextFragment.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/layout/LayoutTextFragment.h
diff --git a/Source/core/rendering/RenderTextFragment.h b/Source/core/layout/LayoutTextFragment.h
similarity index 87%
rename from Source/core/rendering/RenderTextFragment.h
rename to Source/core/layout/LayoutTextFragment.h
index ffce1a7b24043fef2daaa687cbc218c475f51944..c3e65f23754b5305d210a2744ffea31dd8bee4a3 100644
--- a/Source/core/rendering/RenderTextFragment.h
+++ b/Source/core/layout/LayoutTextFragment.h
@@ -20,10 +20,10 @@
*
*/
-#ifndef RenderTextFragment_h
-#define RenderTextFragment_h
+#ifndef LayoutTextFragment_h
+#define LayoutTextFragment_h
-#include "core/rendering/RenderText.h"
+#include "core/layout/LayoutText.h"
namespace blink {
@@ -33,11 +33,11 @@ class FirstLetterPseudoElement;
// first letter and that must therefore have different styles (and positions in the render tree).
// We cache offsets so that text transformations can be applied in such a way that we can recover
// the original unaltered string from our corresponding DOM node.
-class RenderTextFragment final : public RenderText {
+class LayoutTextFragment final : public LayoutText {
public:
- RenderTextFragment(Node*, StringImpl*, int startOffset, int length);
- RenderTextFragment(Node*, StringImpl*);
- virtual ~RenderTextFragment();
+ LayoutTextFragment(Node*, StringImpl*, int startOffset, int length);
+ LayoutTextFragment(Node*, StringImpl*);
+ virtual ~LayoutTextFragment();
virtual void destroy() override;
virtual bool isTextFragment() const override { return true; }
@@ -53,7 +53,7 @@ public:
StringImpl* contentString() const { return m_contentString.get(); }
// The complete text is all of the text in the associated DOM text node.
PassRefPtr<StringImpl> completeText() const;
// The fragment text is the text which will be used by this RenderTextFragment. For
// things like first-letter this may differ from the completeText as we maybe using
// only a portion of the text nodes content.
@@ -64,6 +64,7 @@ public:
virtual void transformText() override;
+ // FIXME: Rename to LayoutTextFragment
virtual const char* renderName() const override final { return "RenderTextFragment"; }
void setFirstLetterPseudoElement(FirstLetterPseudoElement* element) { m_firstLetterPseudoElement = element; }
@@ -87,8 +88,8 @@ private:
FirstLetterPseudoElement* m_firstLetterPseudoElement;
};
-DEFINE_TYPE_CASTS(RenderTextFragment, LayoutObject, object, toRenderText(object)->isTextFragment(), toRenderText(object).isTextFragment());
+DEFINE_TYPE_CASTS(LayoutTextFragment, LayoutObject, object, toLayoutText(object)->isTextFragment(), toLayoutText(object).isTextFragment());
} // namespace blink
-#endif // RenderTextFragment_h
+#endif // LayoutTextFragment_h
« no previous file with comments | « Source/core/layout/LayoutTextCombine.cpp ('k') | Source/core/layout/LayoutTextFragment.cpp » ('j') | no next file with comments »

Powered by Google App Engine
@@ -53,7 +53,7 @@ public:
// The complete text is all of the text in the associated DOM text node.
PassRefPtr<StringImpl> completeText() const;
- // The fragment text is the text which will be used by this RenderTextFragment. For
+ // The fragment text is the text which will be used by this LayoutTextFragment. For
// things like first-letter this may differ from the completeText as we maybe using
// only a portion of the text nodes content.
This is Rietveld 408576698